/***************************************************************************

  Project: BME280 Weather Station on Nokia 5110 LCD demo 
 
  Board: chipKIT UNO32
        
  Connect CLK to Pin 8
  Connect DIN to Pin 9
  Connect DC to Pin 10
  Connect RST to Pin 11
  Connect CS to Pin 12
  
  Written by: Raj Bhatt (Nov 2016)
  www.embedded-lab.com 
  
  Uses Adafruit library for BME280 and
  Nokia 5110 LCD library for chipKIT from Rinky-Dink Electronics. 


  
  This is a library for the BME280 humidity, temperature & pressure sensor

  Designed specifically to work with the Adafruit BME280 Breakout
  ----> http://www.adafruit.com/products/2650

  These sensors use I2C or SPI to communicate, 2 or 4 pins are required
  to interface.

  Adafruit invests time and resources providing this open source code,
  please support Adafruit andopen-source hardware by purchasing products
  from Adafruit!

  Written by Limor Fried & Kevin Townsend for Adafruit Industries.
  BSD license, all text above must be included in any redistribution
 ***************************************************************************/

#include <Wire.h>
#include <SPI.h>
#include <Adafruit_Sensor.h>
#include <Adafruit_BME280.h>
#include <LCD5110_Basic.h>

// Only used for sprintf
#include <stdio.h>

LCD5110 myGLCD(8,9,10,11,12);

Adafruit_BME280 bme;

extern unsigned char SmallFont[];
char tempC[5];
char RH[5];
char pressure[8];
void setup() {
  myGLCD.InitLCD();
  myGLCD.setFont(SmallFont);
  Serial.begin(9600);
  Serial.println(F("BME280 test"));

  if (!bme.begin()) {
    Serial.println("Could not find a valid BME280 sensor, check wiring!");
    while (1);
  }
}

void loop() {
    myGLCD.clrScr();
    Serial.print("Temperature = ");
    float t = bme.readTemperature();
    Serial.print(t);
    Serial.println(" *C");

    Serial.print("Pressure = ");
    float p = bme.readPressure()/100.0;
    Serial.print(p);
    Serial.println(" hPa");
    float h = bme.readHumidity();
    Serial.print("Humidity = ");
    Serial.print(h);
    Serial.println(" %");

    Serial.println();

    myGLCD.print("Nokia 5110 LCD", 0, 0);
    myGLCD.print("+ BME280 Demo", 0, 11);
    sprintf(tempC, "%.1f", t);
    sprintf(RH, "%.1f", h);
    sprintf(pressure, "%.1f", p);
    myGLCD.print("Temp.=", 0, 25);
    myGLCD.print(tempC, 35, 25);
    myGLCD.print("~C", 61, 25);
    myGLCD.print("Hum.=", 0, 35);
    myGLCD.print(RH, 35, 35);
    myGLCD.print("%", 61, 35);
    myGLCD.print("Pr.=", 0, 45);
    myGLCD.print(pressure, 26, 45);
    myGLCD.print("hPa", 64, 45);
   
    delay(2000);
}
